Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreatorV1Client ¶
type CreatorV1Client struct {
// contains filtered or unexported fields
}
CreatorV1Client is used to interact with features provided by the creator group.
func New ¶
func New(c rest.Interface) *CreatorV1Client
New creates a new CreatorV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CreatorV1Client, error)
NewForConfig creates a new CreatorV1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CreatorV1Client
NewForConfigOrDie creates a new CreatorV1Client for the given config and panics if there is an error in the config.
func (*CreatorV1Client) RESTClient ¶
func (c *CreatorV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*CreatorV1Client) Services ¶
func (c *CreatorV1Client) Services() ServiceInterface
type CreatorV1Interface ¶
type CreatorV1Interface interface {
RESTClient() rest.Interface
ServicesGetter
}
type ServiceExpansion ¶
type ServiceExpansion interface{}
type ServiceInterface ¶
type ServiceInterface interface {
Create(*v1.Service) (*v1.Service, error)
Update(*v1.Service) (*v1.Service, error)
Delete(name string, options *metav1.DeleteOptions) error
DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error
Get(name string, options metav1.GetOptions) (*v1.Service, error)
List(opts metav1.ListOptions) (*v1.ServiceList, error)
Watch(opts metav1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1.Service, err error)
ServiceExpansion
}
ServiceInterface has methods to work with Service resources.
type ServicesGetter ¶
type ServicesGetter interface {
Services() ServiceInterface
}
ServicesGetter has a method to return a ServiceInterface. A group's client should implement this interface.